@@ -1863,7 +1863,7 @@ C
       IMPLICIT DOUBLE PRECISION(A-H,O-Z)
       DIMENSION X(MDX,NP),Y(N),THETA(NP),OI(N),WA(N),COV(NCOV),
      1          F0(N),F1(N),F2(N),CI(N),VTHETA(N),GRAD(NP),DELTA(NP),
-     2          RW1(5*NP),RW2(MDX,NP)
+     2          RW1(5*NP),RW2(MDX,NP),HESSNV(NCOV)
       INTEGER NI(N),IW1(NP)
       DATA ZETA,IQ/0.D001,10/
 C
