@@ -2569,7 +2569,7 @@ c     + CALL MESSGE(500,'RLWEIBUD',1)
 C
       DOUBLE PRECISION FUNCTION RLIFWANS(DX,WGT,N,EXWEB,EXPSI,NT,TETA)
       implicit double precision(a-h,o-z)
-      DOUBLE PRECISION ANS,EXWEB,DX,IFW(1),WGT(N),TETA(NT)
+      DOUBLE PRECISION ANS,EXWEB,DX(1),IFW(1),WGT(N),TETA(NT)
       EXTERNAL EXWEB,EXPSI
 C     COMMON/TETAPR/TETA(60)
 C
@@ -3003,7 +3003,7 @@ c      IF (SIGMA.LE.0.) CALL MESSGE(500,'GAUSDD',1)
 C
       DOUBLE PRECISION FUNCTION RLIFLANS(DX,WGT,N,EXGAU,EXPSI,NT,TETA)
       implicit double precision(a-h,o-z)
-      DOUBLE PRECISION ANS,EXGAU,EXMIN,DX,IFL(1),Z,WGT(N),TETA(NT)
+      DOUBLE PRECISION ANS,EXGAU,EXMIN,DX,IFL(1),Z(1),WGT(N),TETA(NT)
       EXTERNAL EXGAU,EXPSI
 c     COMMON/TETAPR/TETA(60)
       DATA NCALL,EXMIN/0,0.D0/
@@ -3015,7 +3015,7 @@ C
         CALL RLMACHD(3,EXMIN)
       ENDIF
       Z=0.D0
-      IF (Z.GT.EXMIN) Z=DEXP(DX)
+      IF (Z(1).GT.EXMIN) Z=DEXP(DX)
       RLIFLANS=0.D0
       ANS=EXGAU(WGT(2),WGT(1),DX)
       IF (ANS.LE.1.D-20) RETURN
